ClientApp class final

Locates and initializes @client components during hydration.

Each @client component will be mounted as a direct child of this component, independent of the actual position of that component in the DOM tree. It allows client components to share a root subtree, which can be useful for sharing state by wrapping this component with one or more InheritedComponents.

Beware that wrapping this component with components that render DOM objects might prevent @client components to be properly hydrated.

Requires Jaspr.initializeApp to be called with the generated ClientOptions before being used.

Inheritance

Constructors

ClientApp()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() Element
Inflates this configuration to a concrete instance.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited