ClientAppBinding class

Global component binding for the client.

Inheritance
Mixed-in types

Constructors

ClientAppBinding()

Properties

currentUrl String
The currently active url.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isClient bool
Whether the current app is run on the client (in the browser)
no setteroverride
rootElement RenderObjectElement?
The Element that is at the root of the hierarchy.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedulerPhase SchedulerPhase
no setterinherited

Methods

addPostFrameCallback(VoidCallback callback) → void
inherited
attachRootComponent(Component app, {String attachTo = 'body', (Node, Node)? attachBetween}) → void
Sets app as the new root of the component tree and performs an initial build
override
completeInitialFrame() → void
override
createRootBuildOwner() BuildOwner
inherited
createRootRenderObject() RenderObject
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportBuildError(Element element, Object error, StackTrace stackTrace) → void
Report an error that occurred during the build process of element.
override
scheduleBuild(VoidCallback buildCallback) → void
Schedules a build and ultimately calls _handleFrame with the provided buildCallback.
inherited
scheduleFrame(VoidCallback frameCallback) → void
Schedules a frame with the provided frameCallback.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited