ClientOptions class final

Global options for configuring Jaspr on the client.

DO NOT USE DIRECTLY. Use the generated defaultClientOptions instead.

Constructors

ClientOptions({void initialize()?, Map<String, ClientLoader> clients = const {}})
const

Properties

clients Map<String, ClientLoader>
final
hashCode int
The hash code for this object.
no setterinherited
initialize → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited