DomRenderText class

Inheritance
Implemented types

Constructors

DomRenderText(String text, DomRenderObject? parent)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextSibling ↔ DomRenderObject?
getter/setter pairinherited
node ↔ Text
latefinaloverride-getter
parent ↔ DomRenderObject?
getter/setter pairinherited
previousSibling ↔ DomRenderObject?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach(covariant RenderObject child, {covariant RenderObject? after}) → void
override
createChildRenderElement(String tag) → RenderElement
inherited
createChildRenderFragment() → RenderFragment
inherited
createChildRenderText(String text) → RenderText
inherited
finalize() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(covariant RenderObject child) → void
override
retakeNode(bool visitNode(Node node)) → Node?
override
toString() → String
A string representation of this object.
inherited
update(String text) → void
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited