Jaspr class abstract final

Main class for initializing the Jaspr framework on the client.

Call Jaspr.initializeApp at the start of your app, before any calls to runApp.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isInitialized bool
no setter
options ClientOptions
no setter

Static Methods

initializeApp({ClientOptions options = const ClientOptions()}) → void