TextDecorationThickness class

The text-decoration-thickness CSS property sets the stroke thickness of the decoration line that is used on text in an element, such as a line-through, underline, or overline.

Read more: MDN text-decoration-thickness

Constructors

TextDecorationThickness.value(Unit value)
Specifies the thickness of the text decoration line, overriding the font file suggestion or the browser default.
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The css value
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

auto → const TextDecorationThickness
The browser chooses an appropriate width for the text decoration line.
fromFont → const TextDecorationThickness
If the font file includes information about a preferred thickness, use that value. If the font file doesn't include this information, behave as if auto was set, with the browser choosing an appropriate thickness.
inherit → const TextDecorationThickness
initial → const TextDecorationThickness
revert → const TextDecorationThickness
revertLayer → const TextDecorationThickness
unset → const TextDecorationThickness