form class final

The <form> HTML element represents a document section containing interactive controls for submitting information.

Inheritance

Constructors

form(List<Component> children, {String? action, FormMethod? method, FormEncType? encType, AutoComplete? autoComplete, String? name, bool noValidate = false, Target? target, String? id, String? classes, Styles? styles, Map<String, String>? attributes, Map<String, EventCallback>? events, Key? key})
The <form> HTML element represents a document section containing interactive controls for submitting information.
const

Properties

action → String?
The URL that processes the form submission. This value can be overridden by a formaction attribute on a <button>, <input type="submit">, or <input type="image"> element. This attribute is ignored when method="dialog" is set.
final
attributes → Map<String, String>?
Additional attributes to apply to the HTML element.
final
autoComplete → AutoComplete?
Indicates whether input elements can by default have their values automatically completed by the browser. autocomplete attributes on form elements override it on <form>.
final
children → List<Component>
The children of this component.
final
classes → String?
The CSS classes to apply to the HTML element, separated by whitespace.
final
encType → FormEncType?
If the value of the method attribute is post, enctype is the MIME type of the form submission.
final
events → Map<String, EventCallback>?
Event listeners to attach to the HTML element.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The id of the HTML element. Must be unique within the document.
final
key → Key?
Controls how one component replaces another component in the tree.
finalinherited
method → FormMethod?
The HTTP method to submit the form with.
final
name → String?
The name of the form. The value must not be the empty string, and must be unique among the form elements in the forms collection that it is in, if any.
final
noValidate → bool
Indicates that the form shouldn't be validated when submitted. If this attribute is not set (and therefore the form is validated), it can be overridden by a formnovalidate attribute on a <button>, <input type="submit">, or <input type="image"> element belonging to the form.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styles → Styles?
The inline styles to apply to the HTML element.
final
target → Target?
Indicates where to display the response after submitting the form. In HTML 4, this is the name/keyword for a frame. In HTML5, it is a name/keyword for a browsing context (for example, tab, window, or iframe).
final

Methods

build(BuildContext context) → Component
Describes the part of the user interface represented by this component.
override
createElement() → Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) → bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited