line class final

The <line> element is an SVG basic shape used to create a line connecting two points.

Inheritance

Constructors

line(List<Component> children, {String? x1, String? y1, String? x2, String? y2, Color? fill, Color? stroke, String? strokeWidth, String? id, String? classes, Styles? styles, Map<String, String>? attributes, Map<String, EventCallback>? events, Key? key})
The <line> element is an SVG basic shape used to create a line connecting two points.
const

Properties

attributes → Map<String, String>?
Additional attributes to apply to the HTML element.
final
children → List<Component>
The children of this component.
final
classes → String?
The CSS classes to apply to the HTML element, separated by whitespace.
final
events → Map<String, EventCallback>?
Event listeners to attach to the HTML element.
final
fill → Color?
The color (or gradient or pattern) used to paint the shape.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The id of the HTML element. Must be unique within the document.
final
key → Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stroke → Color?
The color (or gradient or pattern) used to paint the outline of the shape.
final
strokeWidth → String?
The width of the stroke to be applied to the shape.
final
styles → Styles?
The inline styles to apply to the HTML element.
final
x1 → String?
Defines the x-axis coordinate of the line starting point.
final
x2 → String?
Defines the x-axis coordinate of the line ending point.
final
y1 → String?
Defines the y-axis coordinate of the line starting point.
final
y2 → String?
Defines the y-axis coordinate of the line ending point.
final

Methods

build(BuildContext context) → Component
Describes the part of the user interface represented by this component.
override
createElement() → Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) → bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited