meta class final

The <meta> HTML element represents metadata that cannot be represented by other HTML meta-related elements, like <base >, <link >, <script >, <style > or <title >.

Inheritance

Constructors

meta({String? name, String? content, String? charset, String? httpEquiv, String? id, String? classes, Styles? styles, Map<String, String>? attributes, Map<String, EventCallback>? events, Key? key})
The <meta> HTML element represents metadata that cannot be represented by other HTML meta-related elements, like <base >, <link >, <script >, <style > or <title >.
const

Properties

attributes → Map<String, String>?
Additional attributes to apply to the HTML element.
final
charset → String?
This attribute declares the document's character encoding. If the attribute is present, its value must be an ASCII case-insensitive match for the string "utf-8", because UTF-8 is the only valid encoding for HTML5 documents. <meta> elements which declare a character encoding must be located entirely within the first 1024 bytes of the document.
final
classes → String?
The CSS classes to apply to the HTML element, separated by whitespace.
final
content → String?
This attribute contains the value for the 'http-equiv' or 'name' attribute, depending on which is used.
final
events → Map<String, EventCallback>?
Event listeners to attach to the HTML element.
final
hashCode → int
The hash code for this object.
no setterinherited
httpEquiv → String?
Defines a pragma directive. The attribute's name, short for http-equivalent, is because all the allowed values are names of particular HTTP headers.
final
id → String?
The id of the HTML element. Must be unique within the document.
final
key → Key?
Controls how one component replaces another component in the tree.
finalinherited
name → String?
The name and content attributes can be used together to provide document metadata in terms of name-value pairs, with the name attribute giving the metadata name, and the content attribute giving the value. See standard metadata names for details about the set of standard metadata names defined in the HTML specification.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styles → Styles?
The inline styles to apply to the HTML element.
final

Methods

build(BuildContext context) → Component
Describes the part of the user interface represented by this component.
override
createElement() → Element
Creates a StatelessElement to manage this component's location in the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldRebuild(covariant Component newComponent) → bool
Implement this method to determine whether a rebuild can be skipped.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited