loop property
If specified, the browser will automatically seek back to the start upon reaching the end of the video.
Implementation
final bool loop;
If specified, the browser will automatically seek back to the start upon reaching the end of the video.
final bool loop;