DomComponent class

Represents a html element in the DOM

Must have a tag and any number of attributes. Accepts a list of children.

Inheritance

Properties

attributes Map<String, String>?
final
children List<Component>?
final
classes String?
final
events Map<String, EventCallback>?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
key Key?
Controls how one component replaces another component in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles Styles?
final
tag String
final

Methods

createElement() Element
Inflates this configuration to a concrete instance.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited