ElementSlot class

Constructors

ElementSlot(int index, Element? previousSibling)

Properties

hashCode int
The hash code for this object.
no setteroverride
index int
The index of this slot in the parent's child list.
final
previousSibling Element?
The previous sibling of this slot in the parent's child list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target RenderObjectElement?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override