RawableRenderObject class abstract

Implemented types
Implementers

Constructors

RawableRenderObject()

Properties

hashCode int
The hash code for this object.
no setterinherited
node → Node?
no setterinherited
parent RenderObject?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach(covariant RenderObject child, {covariant RenderObject? after}) → void
inherited
createChildRenderElement(String tag) RenderElement
inherited
createChildRenderFragment() RenderFragment
inherited
createChildRenderText(String text, [bool rawHtml = false]) RenderText
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(covariant RenderObject child) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited