mustCallSuper top-level constant
Object
const mustCallSuper
Annotation on instance member that overriding members must call.
Used to annotate an instance member (method, getter, setter, operator, or field). Indicates that every invocation of an overriding member will also invoke the current implementation of the member. In addition, every overriding member is implicitly annotated with this same annotation.
Note that private members with this annotation cannot be overridden outside of the library that defines the annotated member.
Tools, such as the analyzer, can provide feedback if
- the annotation is associated with anything other than an instance member,
- the annotation is applied to an instance member with no concrete implementation, or
- a member that overrides a member that has this annotation can return without invoking the overridden member.
Implementation
const Object mustCallSuper = _MustCallSuper();