ClientTarget<T extends Component> class final

The target configuration for a @client component.

DO NOT USE DIRECTLY. Use the generated defaultServerOptions instead.

Constructors

ClientTarget(String name, {Map<String, Object?> params(T component)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
params Map<String, Object?> Function(T component)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dataFor(T component) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited