Jaspr class abstract final

Main class for initializing the Jaspr framework on the server.

Call Jaspr.initializeApp at the start of your app, before any calls to runApp.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

allowedPathSuffixes List<String>
no setter
isInitialized bool
no setter
options ServerOptions
no setter
useIsolates bool
no setter

Static Methods

initializeApp({ServerOptions options = const ServerOptions(), bool useIsolates = false, List<String> allowedPathSuffixes = const ['html', 'htm', 'xml']}) → void