ServerApp class final
An object to be returned from runApp on the server and provide access to the internal http server.
Constructors
- ServerApp.run(SetupFunction setup)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- createTestHandler → Handler Function(SetupHandler handle, {Client? client, Handler? fileHandler})
-
final
-
onReassemble
→ Stream<
Object> -
no setter
Static Methods
-
addMiddleware(
Middleware middleware) → void - Adds a shelf middleware to the server application.
-
requestRouteGeneration(
String route, {String? lastMod, String? changefreq, double? priority}) → Future< void>