ServerOptions class final

Global options for configuring Jaspr on the server.

DO NOT USE DIRECTLY. Use the generated defaultServerOptions instead.

Constructors

ServerOptions({String? clientId, Map<Type, ClientTarget<Component>>? clients, List<StyleRule> styles()?})
const

Properties

clientId String?
final
clients Map<Type, ClientTarget<Component>>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styles List<StyleRule> Function()?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited