runApp function
Main entry point on the server.
Implementation
// TODO: Add hint about usage of global variables and isolate state.
void runApp(Component app) {
_checkInitialized('runApp');
ServerApp.run(_createSetup(app));
}
Main entry point on the server.
// TODO: Add hint about usage of global variables and isolate state.
void runApp(Component app) {
_checkInitialized('runApp');
ServerApp.run(_createSetup(app));
}