ClientLoader class final
The loader configuration for a @client component.
DO NOT USE DIRECTLY.
Use the generated defaultClientOptions instead.
Constructors
-
ClientLoader(ClientBuilder builder, {Future<
void> loader()?})
Properties
- builder → ClientBuilder
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
loadedBuilder
→ FutureOr<
ClientBuilder> -
Returns the loaded ClientBuilder.
no setter
-
loader
→ Future<
void> Function()? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited