Fragment class
A utility component that renders its children without any wrapper element.
This is meant to be used in places where you want to render multiple components, but only a single component is allowed by the API.
Properties
Methods
-
createElement(
) → Element -
Inflates this configuration to a concrete instance.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited