AttachAdapter class
- Inheritance
-
- Object
- RenderAdapter
- AttachAdapter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetElements
→ Map<
String, ({Map< String, String> attributes, List<({int depth, ChildListRange range})> children})> -
final
Methods
-
apply(
MarkupRenderObject root) → void -
override
-
createDocumentStructure(
MarkupRenderObject root) → (MarkupRenderElement, MarkupRenderElement, MarkupRenderElement) -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepare(
) → FutureOr< void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
register(
BuildContext context, AttachDocument item) → void